@@ -6,7 +6,9 @@ except ImportError:  # pragma: no cover
 from ._context import *
 from ._general import *
 from ._filters import *
+from ._grid import *
 from .utils import *
+from ._datasets import *
 
 
 set_context()
